<?php

/*
Plugin Name: easytweet
Plugin URI: http://blog.submute.net
Version: v1.0
Author: <a href="http://www.wellsoliver.com">Wells Oliver</a>
Description: Easy. Tweets.
*/

// some basic defines
define("TWITTER_URL", "http://twitter.com/statuses/update.json");
define("EASYBASE", dirname(__FILE__));
define("EASYVERSION", 1.0);

// shows the form on the new post display
function easytweet_showPostForm() {
	
	$on = (get_option("easytweet_default") === "yes") ? "CHECKED" : "";
	$off = (get_option("easytweet_default") === "no" || get_option("easytweet_default") === "") ? "CHECKED" : "";
	
	echo '<div class="postbox"><h3>easytweet</h3>';
	echo '<div class="inside"><p>Tweet about this post?&nbsp;&nbsp;';
	
	echo '<input type="radio" name="easytweet_notify" id="easytweet_notify_no" value="no" ' . $off . ' /> <label for="easytweet_notify_no">No</label>&nbsp;&nbsp;';
	echo '<input type="radio" name="easytweet_notify" id="easytweet_notify_yes" value="yes" ' . $on . ' /> <label for="easytweet_notify_yes">Yes</label>&nbsp;&nbsp;';

	echo '</p></div>';
	echo '</div>';
}

// do the tweet
function easytweet_tweet($post_id = 0) {

		if ($post_id == 0 || get_post_meta($post_id, 'easytweet_tweeted', true) == '1' || get_post_meta($post_id, 'easytweet_notify', TRUE) !== 'yes') {
			return;
		}
		
		$post = get_post($post_id);
		$username = get_option("easytweet_twitter_username");
		$password = get_option("easytweet_twitter_password");
		$format = get_option("easytweet_twitter_tweetformat");
		$use_tiny = get_option("easytweet_tiny") == "yes";
		
		if ($post->post_status == "private") {
			return;
		}
		
		if (empty($username) || empty($password) || empty($format)) {
			return;
		}
		
		require_once(sprintf("%s%s/class-snoopy.php", ABSPATH, WPINC));

		$snoopy = new Snoopy;
		$snoopy->agent = "easytweet " . EASYVERSION . " http://blog.wellsoliver.com";
		
		$permalink = get_permalink($post_id);

		if ($use_tiny) {
			$tiny = sprintf("http://tinyurl.com/api-create.php?url=%s", $permalink);

			$snoopy->submit($tiny);

			if (isset($snoopy->results) && empty($snoopy->results) === FALSE) {
				$short_url = $snoopy->results;
			} else {
				$short_url = $permalink;
			}
		}

		$tweet = str_replace("%%TITLE%%", $post->post_title, $format);
		$tweet = str_replace("%%URL%%", $short_url, $tweet);
		
		$snoopy->rawheaders = array(
			"X-Twitter-Client" => "easytweet",
			"X-Twitter-Client-Version" => EASYVERSION,
			"X-Twitter-Client-URL" => "http://blog.wellsoliver.com"
		);
		$snoopy->user = $username;
		$snoopy->pass = $password;
		$snoopy->submit(
			TWITTER_URL,
			array(
				"status" => $tweet,
				"source" => "easytweet " . EASYVERSION
			)
		);
		
		if (stripos($snoopy->response_code, "200")) {
			add_post_meta($post_id, "easytweet_tweeted", "1", TRUE);			
		}
}

// saves the options for tweeting for a given post
function easytweet_savePostOptions($post_id, $post = FALSE) {

	$post = get_post($post_id);
	
	if ($post === FALSE || $post->post_type == "revision") {
		return;
	}
	
	$posted = $_POST['easytweet_notify'];
	
	if (update_post_meta($post_id, "easytweet_notify", $posted) === FALSE) {
		add_post_meta($post_id, "easytweet_notify", $posted);
	}
	
}

// shows the administration options for the plugin
function easytweet_showOptionsForm() {
	require_once EASYBASE . "/options.php";
}

// handles the administration form
function easytweet_doAdminForm() {
	add_options_page('easyTweet', 'easyTweet', 8, 'easytweet', 'easytweet_showOptionsForm');
}

// register the plugin settings
function easytweet_registerSettings() {
	
	register_setting("easytweet", "easytweet_twitter_username");
	register_setting("easytweet", "easytweet_twitter_password");
	register_setting("easytweet", "easytweet_tiny");
	register_setting("easytweet", "easytweet_default");
	register_setting("easytweet", "easytweet_twitter_tweetformat");
}

// add a "Settings" link to the list of plugins
function easytweet_action_links($links, $file) {
	static $this_plugin;

	$this_plugin = plugin_basename(__FILE__);
	
	if ($file == $this_plugin) {
		array_unshift($links, "<a href='options-general.php?page=easytweet'>Settings</a>");
	}
	
	return $links;
}

// hook up with wordpress!
add_filter('plugin_action_links', 'easytweet_action_links', 1, 2);
add_action('edit_form_advanced', 'easytweet_showPostForm');
add_action('publish_post', 'easytweet_tweet', 99);
add_action('publish_post', 'easytweet_savePostOptions', 1, 2);
add_action('save_post', 'easytweet_savePostOptions', 1, 2);
if (is_admin()) {
	add_action('admin_menu', 'easytweet_doAdminForm');
	add_action('admin_init', 'easytweet_registerSettings');
}

?>
